package sun.security.krb5.internal.rcache;

import sun.security.krb5.internal.Krb5;
import java.util.Iterator;
import sun.security.krb5.internal.KrbApErrException;
import sun.security.krb5.internal.KerberosTime;
import java.util.concurrent.ConcurrentHashMap;
import java.util.Map;
import sun.security.krb5.internal.ReplayCache;

public class MemoryCache extends ReplayCache
{
    private static final int lifespan;
    private static final boolean DEBUG;
    private final Map<String, AuthList> content;
    
    public MemoryCache() {
        this.content = new ConcurrentHashMap();
    }
    
    @Override
    public synchronized void checkAndStore(KerberosTime kerberosTime, AuthTimeWithHash obj) throws KrbApErrException {
        String string = obj.client + "|" + obj.server;
        ((AuthList)this.content.computeIfAbsent(string, p0/* java.lang.String, */ -> new AuthList(MemoryCache.lifespan))).put(obj, kerberosTime);
        if (MemoryCache.DEBUG) {
            System.out.println("MemoryCache: add " + obj + " to " + string);
        }
    }
    
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        Iterator<AuthList> iterator = this.content.values().iterator();
        while (iterator.hasNext()) {
            sb.append(((AuthList)iterator.next()).toString());
        }
        return sb.toString();
    }
    
    static {
        lifespan = KerberosTime.getDefaultSkew();
        DEBUG = Krb5.DEBUG;
    }
}
